translate.misc.typecheck.CheckType

Package translate :: Package misc :: Package typecheck :: Class CheckType |
[hide private]
[frames] | no frames]

# Class CheckType

source code

Instance Methods | [hide private]
__repr__(self) str(x) | source code
__str__(self) str(x) | source code
__eq__(self, other) | source code
__ne__(self, other) | source code
__hash__(self) hash(x) | source code
__typecheck__(self, func, obj) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Methods | [hide private]
__typesig__(cls, obj) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __repr__(self) (Representation operator) | source code
str(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### __hash__(self) (Hashing function) | source code
hash(x) Overrides: object.__hash__ (inherited documentation)